summaryrefslogtreecommitdiffstats
path: root/knode/kncollectionviewitem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'knode/kncollectionviewitem.cpp')
-rw-r--r--knode/kncollectionviewitem.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/knode/kncollectionviewitem.cpp b/knode/kncollectionviewitem.cpp
index 35f2ae2c..0be47ddc 100644
--- a/knode/kncollectionviewitem.cpp
+++ b/knode/kncollectionviewitem.cpp
@@ -32,15 +32,15 @@
#include "knconfigmanager.h"
-KNCollectionViewItem::KNCollectionViewItem( KFolderTree *parent, Protocol protocol, Type type) :
- KFolderTreeItem(parent, TQString::null, protocol, type), coll(0)
+KNCollectionViewItem::KNCollectionViewItem( KFolderTree *tqparent, Protocol protocol, Type type) :
+ KFolderTreeItem(tqparent, TQString(), protocol, type), coll(0)
{
setIcon();
}
KNCollectionViewItem::KNCollectionViewItem( KFolderTreeItem *it, Protocol protocol, Type type, int unread, int total ) :
- KFolderTreeItem(it, TQString::null, protocol, type, unread, total), coll(0)
+ KFolderTreeItem(it, TQString(), protocol, type, unread, total), coll(0)
{
setIcon();
}
@@ -137,7 +137,7 @@ void KNCollectionViewItem::paintCell( TQPainter * p, const TQColorGroup & cg,int
if (px)
pxWidth += px->width();
// temporary set the squeezed text and use the parent class to paint it
TQString curText = text( column );
if ( p->fontMetrics().width( curText ) > width - pxWidth ) {
setText( column, squeezeFolderName( curText, p->fontMetrics(), width - pxWidth ) );
@@ -157,7 +157,7 @@ TQString KNCollectionViewItem::squeezeFolderName( const TQString &text,
int curPos = 0, nextPos = 0;
TQString temp;
while ( (uint)fm.width(t) > width && nextPos != -1 ) {
- nextPos = t.find('.', curPos);
+ nextPos = t.tqfind('.', curPos);
if ( nextPos != -1 ) {
temp = t[curPos];
t.tqreplace( curPos, nextPos - curPos, temp );
@@ -137,7 +137,7 @@ void KNCollectionViewItem::paintCell( TQPainter * p, const TQColorGroup & cg,int
if (px)
pxWidth += px->width();
- // temporary set the squeezed text and use the parent class to paint it
+ // temporary set the squeezed text and use the tqparent class to paint it
TQString curText = text( column );
if ( p->fontMetrics().width( curText ) > width - pxWidth ) {